@@ -2,7 +2,7 @@
 #define LEMON_ASSERT_H
 
 void lemon_assert(char *file, int line);
-#ifndef NDEBUG
+#ifndef MLR_DSL_NDEBUG
 #  define assert(X) if(!(X))lemon_assert(__FILE__,__LINE__)
 #else
 #  define assert(X)
