@@ -4,15 +4,18 @@ import (
 	"fmt"
 	"os"
 	"runtime"
+	"runtime/debug"
 	"runtime/pprof"
 
-	"miller/cli"
-	"miller/stream"
+	"miller/src/auxents"
+	"miller/src/cli"
+	"miller/src/stream"
 )
 
 // ----------------------------------------------------------------
 func main() {
-	runtime.GOMAXPROCS(4) // Seems reasonable these days
+	runtime.GOMAXPROCS(4)   // Seems reasonable these days
+	debug.SetGCPercent(500) // Empirical: See README-profiling.md
 
 	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 	// CPU profiling
@@ -23,11 +26,7 @@ func main() {
 	// and properly stopping the profile only when main ends via chan-sync,
 	// results in a zero-length pprof file.
 	//
-	// Usage:
-	// * mlr --cpuprofile cpu.pprof put -f u/example.mlr then nothing ~/tmp/huge > /dev/null
-	// * go tool pprof mlr cpu.pprof
-	//   top10
-	// * go tool pprof --pdf mlr cpu.pprof > mlr-call-graph.pdf
+	// Please see README-profiling.md for more information.
 
 	if len(os.Args) >= 3 && os.Args[1] == "--cpuprofile" {
 		profFilename := os.Args[2]
@@ -49,7 +48,10 @@ func main() {
 	}
 
 	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-	// Start of Miller main per se
+	// 'mlr repl' or 'mlr lecat' or any other non-miller-per-se toolery which
+	// is delivered (for convenience) within the mlr executable. If argv[1] is
+	// found then this function will not return.
+	auxents.Dispatch(os.Args)
 
 	options, recordTransformers, err := cli.ParseCommandLine(os.Args)
 	if err != nil {
